@@ -3,6 +3,8 @@ package org.jsoup.nodes;
 import org.jsoup.Jsoup;
 import org.junit.Test;
 
+import static org.jsoup.nodes.Document.OutputSettings;
+import static org.jsoup.nodes.Entities.EscapeMode.*;
 import static org.junit.Assert.*;
 
 import java.nio.charset.Charset;
@@ -10,16 +12,16 @@ import java.nio.charset.Charset;
 public class EntitiesTest {
     @Test public void escape() {
         String text = "Hello &<> Å å π 新 there ¾ ©";
-        String escapedAscii = Entities.escape(text, Charset.forName("ascii").newEncoder(), Entities.EscapeMode.base);
-        String escapedAsciiFull = Entities.escape(text, Charset.forName("ascii").newEncoder(), Entities.EscapeMode.extended);
-        String escapedAsciiXhtml = Entities.escape(text, Charset.forName("ascii").newEncoder(), Entities.EscapeMode.xhtml);
-        String escapedUtfFull = Entities.escape(text, Charset.forName("UTF-8").newEncoder(), Entities.EscapeMode.base);
-        String escapedUtfMin = Entities.escape(text, Charset.forName("UTF-8").newEncoder(), Entities.EscapeMode.xhtml);
+        String escapedAscii = Entities.escape(text, new OutputSettings().charset("ascii").escapeMode(base));
+        String escapedAsciiFull = Entities.escape(text, new OutputSettings().charset("ascii").escapeMode(extended));
+        String escapedAsciiXhtml = Entities.escape(text, new OutputSettings().charset("ascii").escapeMode(xhtml));
+        String escapedUtfFull = Entities.escape(text, new OutputSettings().charset("UTF-8").escapeMode(base));
+        String escapedUtfMin = Entities.escape(text, new OutputSettings().charset("UTF-8").escapeMode(xhtml));
 
         assertEquals("Hello &amp;&lt;&gt; &Aring; &aring; &#x3c0; &#x65b0; there &frac34; &copy;", escapedAscii);
         assertEquals("Hello &amp;&lt;&gt; &angst; &aring; &pi; &#x65b0; there &frac34; &copy;", escapedAsciiFull);
         assertEquals("Hello &amp;&lt;&gt; &#xc5; &#xe5; &#x3c0; &#x65b0; there &#xbe; &#xa9;", escapedAsciiXhtml);
-        assertEquals("Hello &amp;&lt;&gt; &Aring; &aring; π 新 there &frac34; &copy;", escapedUtfFull);
+        assertEquals("Hello &amp;&lt;&gt; Å å π 新 there ¾ ©", escapedUtfFull);
         assertEquals("Hello &amp;&lt;&gt; Å å π 新 there ¾ ©", escapedUtfMin);
         // odd that it's defined as aring in base but angst in full
 
@@ -33,9 +35,9 @@ public class EntitiesTest {
 
     @Test public void escapeSupplementaryCharacter(){
         String text = new String(Character.toChars(135361));
-        String escapedAscii = Entities.escape(text, Charset.forName("ascii").newEncoder(), Entities.EscapeMode.base);
+        String escapedAscii = Entities.escape(text, new OutputSettings().charset("ascii").escapeMode(base));
         assertEquals("&#x210c1;", escapedAscii);
-        String escapedUtf = Entities.escape(text, Charset.forName("UTF-8").newEncoder(), Entities.EscapeMode.base);
+        String escapedUtf = Entities.escape(text, new OutputSettings().charset("UTF-8").escapeMode(base));
         assertEquals(text, escapedUtf);
     }
 
@@ -56,7 +58,8 @@ public class EntitiesTest {
     
     @Test public void caseSensitive() {
         String unescaped = "Ü ü & &";
-        assertEquals("&Uuml; &uuml; &amp; &amp;", Entities.escape(unescaped, Charset.forName("ascii").newEncoder(), Entities.EscapeMode.extended));
+        assertEquals("&Uuml; &uuml; &amp; &amp;",
+                Entities.escape(unescaped, new OutputSettings().charset("ascii").escapeMode(extended)));
         
         String escaped = "&Uuml; &uuml; &amp; &AMP";
         assertEquals("Ü ü & &", Entities.unescape(escaped));
@@ -72,9 +75,12 @@ public class EntitiesTest {
     @Test public void letterDigitEntities() {
         String html = "<p>&sup1;&sup2;&sup3;&frac14;&frac12;&frac34;</p>";
         Document doc = Jsoup.parse(html);
+        doc.outputSettings().charset("ascii");
         Element p = doc.select("p").first();
         assertEquals("&sup1;&sup2;&sup3;&frac14;&frac12;&frac34;", p.html());
         assertEquals("¹²³¼½¾", p.text());
+        doc.outputSettings().charset("UTF-8");
+        assertEquals("¹²³¼½¾", p.html());
     }
 
     @Test public void noSpuriousDecodes() {
